# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`aptly`](#aptly): aptly is a swiss army knife for Debian repository management
* [`aptly::api`](#aptly--api): Install and configure Aptly's API Service

### Defined types

* [`aptly::mirror`](#aptly--mirror): aptly::mirror

Create a mirror using `aptly mirror create`. It will not update, snapshot,
or publish the mirror for you, because it will take a long time and it
doesn't make sense to schedule these actions frequenly in Puppet.

NB: This will not recreate the mirror if the params change! You will need
to manually `aptly mirror drop <name>` after also dropping all snapshot
and publish references.
* [`aptly::repo`](#aptly--repo): aptly::repo

Create a repository using `aptly create`. It will not snapshot, or update the
repository for you, because it will take a long time and it doesn't make sense
to schedule these actions frequently in Puppet.
* [`aptly::snapshot`](#aptly--snapshot): Create a snapshot using `aptly snapshot`.

## Classes

### <a name="aptly"></a>`aptly`

aptly is a swiss army knife for Debian repository management

#### Parameters

The following parameters are available in the `aptly` class:

* [`package_ensure`](#-aptly--package_ensure)
* [`config_file`](#-aptly--config_file)
* [`config_contents`](#-aptly--config_contents)
* [`config`](#-aptly--config)
* [`repo`](#-aptly--repo)
* [`key_server`](#-aptly--key_server)
* [`user`](#-aptly--user)
* [`aptly_repos`](#-aptly--aptly_repos)
* [`aptly_mirrors`](#-aptly--aptly_mirrors)

##### <a name="-aptly--package_ensure"></a>`package_ensure`

Data type: `String`

Ensure parameter to pass to the package resource.

Default value: `'present'`

##### <a name="-aptly--config_file"></a>`config_file`

Data type: `Stdlib::Absolutepath`

Absolute path to the configuration file. Defaults to

Default value: `'/etc/aptly.conf'`

##### <a name="-aptly--config_contents"></a>`config_contents`

Data type: `Optional[String]`

Contents of the config file.

Default value: `undef`

##### <a name="-aptly--config"></a>`config`

Data type: `Hash`

Hash of configuration options for `/etc/aptly.conf`. See http://www.aptly.info/#configuration

Default value: `{}`

##### <a name="-aptly--repo"></a>`repo`

Data type: `Boolean`

Whether to configure an apt::source for `repo.aptly.info`. You might want to disable this when you've mirrored that yourself.

Default value: `true`

##### <a name="-aptly--key_server"></a>`key_server`

Data type: `String`

Key server to use when `$repo` is true.

Default value: `'keyserver.ubuntu.com'`

##### <a name="-aptly--user"></a>`user`

Data type: `String`

The user to use when performing an aptly command

Default value: `'root'`

##### <a name="-aptly--aptly_repos"></a>`aptly_repos`

Data type: `Hash`

Hash of aptly repos which is passed to aptly::repo

Default value: `{}`

##### <a name="-aptly--aptly_mirrors"></a>`aptly_mirrors`

Data type: `Hash`

Hash of aptly mirrors which is passed to aptly::mirror

Default value: `{}`

### <a name="aptly--api"></a>`aptly::api`

Install and configure Aptly's API Service

#### Parameters

The following parameters are available in the `aptly::api` class:

* [`ensure`](#-aptly--api--ensure)
* [`user`](#-aptly--api--user)
* [`group`](#-aptly--api--group)
* [`listen`](#-aptly--api--listen)
* [`log`](#-aptly--api--log)
* [`enable_cli_and_http`](#-aptly--api--enable_cli_and_http)

##### <a name="-aptly--api--ensure"></a>`ensure`

Data type: `Enum['stopped','running']`

Ensure to pass on to service type

Default value: `running`

##### <a name="-aptly--api--user"></a>`user`

Data type: `String[1]`

User to run the service as.

Default value: `'root'`

##### <a name="-aptly--api--group"></a>`group`

Data type: `String[1]`

Group to run the service as.

Default value: `'root'`

##### <a name="-aptly--api--listen"></a>`listen`

Data type: `Pattern['^([0-9.]*:[0-9]+$|unix:)']`

What IP/port to listen on for API requests.

Default value: `':8080'`

##### <a name="-aptly--api--log"></a>`log`

Data type: `Enum['none','log']`

Enable or disable Upstart logging.

Default value: `'none'`

##### <a name="-aptly--api--enable_cli_and_http"></a>`enable_cli_and_http`

Data type: `Boolean`

Enable concurrent use of command line (CLI) and HTTP APIs with the same Aptly root.

Default value: `false`

## Defined types

### <a name="aptly--mirror"></a>`aptly::mirror`

aptly::mirror

Create a mirror using `aptly mirror create`. It will not update, snapshot,
or publish the mirror for you, because it will take a long time and it
doesn't make sense to schedule these actions frequenly in Puppet.

NB: This will not recreate the mirror if the params change! You will need
to manually `aptly mirror drop <name>` after also dropping all snapshot
and publish references.

#### Parameters

The following parameters are available in the `aptly::mirror` defined type:

* [`location`](#-aptly--mirror--location)
* [`key`](#-aptly--mirror--key)
* [`filter`](#-aptly--mirror--filter)
* [`release`](#-aptly--mirror--release)
* [`repos`](#-aptly--mirror--repos)
* [`architectures`](#-aptly--mirror--architectures)
* [`with_sources`](#-aptly--mirror--with_sources)
* [`with_udebs`](#-aptly--mirror--with_udebs)
* [`filter_with_deps`](#-aptly--mirror--filter_with_deps)
* [`environment`](#-aptly--mirror--environment)
* [`keyring`](#-aptly--mirror--keyring)

##### <a name="-aptly--mirror--location"></a>`location`

Data type: `String`

URL of the APT repo.

##### <a name="-aptly--mirror--key"></a>`key`

Data type: `Variant[String[1], Hash[String[1],Variant[Array,Integer[1],String[1]]]]`

This can either be a key id or a hash including key options. If using a hash, key => { 'id' => <id> } must be specified

Default value: `{}`

##### <a name="-aptly--mirror--filter"></a>`filter`

Data type: `Optional[String[1]]`

Package query that is applied to packages in the mirror

Default value: `undef`

##### <a name="-aptly--mirror--release"></a>`release`

Data type: `String`

Distribution to mirror for.

Default value: `$facts['os']['distro']['codename']`

##### <a name="-aptly--mirror--repos"></a>`repos`

Data type: `Array`

Components to mirror. If an empty array then aptly will default to mirroring all components.

Default value: `[]`

##### <a name="-aptly--mirror--architectures"></a>`architectures`

Data type: `Array`

Architectures to mirror. If attribute is ommited Aptly will mirror all available architectures.

Default value: `[]`

##### <a name="-aptly--mirror--with_sources"></a>`with_sources`

Data type: `Boolean`

Boolean to control whether Aptly should download source packages in addition to binary packages.

Default value: `false`

##### <a name="-aptly--mirror--with_udebs"></a>`with_udebs`

Data type: `Boolean`

Boolean to control whether Aptly should also download .udeb packages.

Default value: `false`

##### <a name="-aptly--mirror--filter_with_deps"></a>`filter_with_deps`

Data type: `Boolean`

Boolean to control whether when filtering to include dependencies of matching packages as well

Default value: `false`

##### <a name="-aptly--mirror--environment"></a>`environment`

Data type: `Array`

Optional environment variables to pass to the exec. Example: ['http_proxy=http://127.0.0.2:3128']

Default value: `[]`

##### <a name="-aptly--mirror--keyring"></a>`keyring`

Data type: `String`

path to the keyring used by aptly

Default value: `'/etc/apt/trusted.gpg'`

### <a name="aptly--repo"></a>`aptly::repo`

aptly::repo

Create a repository using `aptly create`. It will not snapshot, or update the
repository for you, because it will take a long time and it doesn't make sense
to schedule these actions frequently in Puppet.

#### Parameters

The following parameters are available in the `aptly::repo` defined type:

* [`architectures`](#-aptly--repo--architectures)
* [`comment`](#-aptly--repo--comment)
* [`component`](#-aptly--repo--component)
* [`distribution`](#-aptly--repo--distribution)

##### <a name="-aptly--repo--architectures"></a>`architectures`

Data type: `Array`

Specify the list of supported architectures as an Array. If ommited Aptly assumes the repository.

Default value: `[]`

##### <a name="-aptly--repo--comment"></a>`comment`

Data type: `Optional[String[1]]`

Specifiy a comment to be set for the repository.

Default value: `undef`

##### <a name="-aptly--repo--component"></a>`component`

Data type: `Optional[String[1]]`

Specify which component to put the package in. This option will only works for aptly version >= 0.5.0.

Default value: `undef`

##### <a name="-aptly--repo--distribution"></a>`distribution`

Data type: `Optional[String[1]]`

Specify the default distribution to be used when publishing this repository.

Default value: `undef`

### <a name="aptly--snapshot"></a>`aptly::snapshot`

Create a snapshot using `aptly snapshot`.

#### Parameters

The following parameters are available in the `aptly::snapshot` defined type:

* [`repo`](#-aptly--snapshot--repo)
* [`mirror`](#-aptly--snapshot--mirror)

##### <a name="-aptly--snapshot--repo"></a>`repo`

Data type: `Optional[String[1]]`

Create snapshot from given repo.

Default value: `undef`

##### <a name="-aptly--snapshot--mirror"></a>`mirror`

Data type: `Optional[String[1]]`

Create snapshot from given mirror.

Default value: `undef`

